@@ -11,18 +11,18 @@ func (c *Client) PingC2S(jid, server string) error {
 	if server == "" {
 		server = c.domain
 	}
-	_, err := fmt.Fprintf(c.stanzaWriter, "<iq from='%s' to='%s' id='c2s1' type='get'>"+
+	_, err := fmt.Fprintf(c.stanzaWriter, "<iq from='%s' to='%s' id='%s' type='get'>"+
 		"<ping xmlns='urn:xmpp:ping'/>"+
 		"</iq>\n",
-		xmlEscape(jid), xmlEscape(server))
+		xmlEscape(jid), xmlEscape(server), getUUIDv4())
 	return err
 }
 
 func (c *Client) PingS2S(fromServer, toServer string) error {
-	_, err := fmt.Fprintf(c.stanzaWriter, "<iq from='%s' to='%s' id='s2s1' type='get'>"+
+	_, err := fmt.Fprintf(c.stanzaWriter, "<iq from='%s' to='%s' id='%s' type='get'>"+
 		"<ping xmlns='urn:xmpp:ping'/>"+
 		"</iq>\n",
-		xmlEscape(fromServer), xmlEscape(toServer))
+		xmlEscape(fromServer), xmlEscape(toServer), getUUIDv4())
 	return err
 }
 
